<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Thien Hau <thienhau.9a14@gmail.com>
 */
$lang['menu']                  = 'Cài đặt cấu hình';
$lang['error']                 = 'Không thể cập nhật cài đặt do giá trị không hợp lệ, vui lòng xem lại các thay đổi của bạn và gửi lại.
                       <br />(Các) giá trị không chính xác sẽ được hiển thị bao quanh viền đỏ.';
$lang['updated']               = 'Đã cập nhật cài đặt thành công .';
$lang['nochoice']              = '(không có lựa chọn nào khác)';
$lang['locked']                = 'Không thể cập nhật tập tin cài đặt, nếu điều này là vô ý, <br />
                       đảm bảo tên tập tin cài đặt cục bộ và quyền đều chính xác.';
$lang['danger']                = 'Nguy hiểm: Thay đổi tùy chọn này có thể khiến wiki và menu cấu hình của bạn không thể truy cập được.';
$lang['warning']               = 'Cảnh báo: Thay đổi tùy chọn này có thể gây ra hành vi ngoài ý muốn.';
$lang['security']              = 'Cảnh báo bảo mật: Thay đổi tùy chọn này có thể gây ra rủi ro bảo mật.';
$lang['_configuration_manager'] = 'Quản lý cấu hình';
$lang['_header_template']      = 'Chủ đề';
$lang['_header_undefined']     = 'Cài đặt không xác định';
$lang['_basic']                = 'Cơ bản';
$lang['_display']              = 'Hiển thị';
$lang['_authentication']       = 'Xác thực';
$lang['_anti_spam']            = 'Chống Spam';
$lang['_editing']              = 'Sửa đổi';
$lang['_links']                = 'Liên kết';
$lang['_media']                = 'Phương tiện';
$lang['_notifications']        = 'Thông báo';
$lang['_syndication']          = 'Đồng bộ (RSS)';
$lang['_advanced']             = 'Nâng cao';
$lang['_network']              = 'Mạng';
$lang['_msg_setting_undefined'] = 'Không có cài đặt siêu dữ liệu.';
$lang['_msg_setting_no_class'] = 'Không có lớp thiết lập.';
$lang['_msg_setting_no_known_class'] = 'Lớp thiết lập không có sẵn.';
$lang['_msg_setting_no_default'] = 'Không có giá trị mặc định.';
$lang['title']                 = 'Tiêu đề Wiki (tên wiki của bạn)';
$lang['start']                 = 'Tên trang sử dụng làm điểm bắt đầu cho mỗi không gian tên';
$lang['lang']                  = 'Ngôn ngữ giao diện';
$lang['template']              = 'Chủ đề (thiết kế của wiki)';
$lang['tagline']               = 'Khẩu hiệu (nếu chủ đề hỗ trợ)';
$lang['sidebar']               = 'Tên trang thanh bên (nếu chủ đề hỗ trợ), để trống sẽ vô hiệu hóa thanh bên';
$lang['license']               = 'Nội dung của bạn nên được phát hành dưới?';
$lang['savedir']               = 'Đường dẫn lưu dữ liệu';
$lang['basedir']               = 'Đường dẫn máy chủ (VD. <code>/dokuwiki/</code>). Để trống để tự động phát hiện.';
$lang['baseurl']               = 'URL máy chủ (VD. <code>http://www.yourserver.com</code>). Để trống để tự động phát hiện.';
$lang['cookiedir']             = 'Đường dẫn cookie. Để trống để sử dụng baseurl.';
$lang['dmode']                 = 'Chế độ tạo đường dẫn';
$lang['fmode']                 = 'Chế độ tạo tập tin';
$lang['allowdebug']            = 'Cho phép gỡ lỗi. <b>Vô hiệu hóa nếu không cần thiết!</ b>';
$lang['recent']                = 'Số lượng mục trên mỗi trang trong thay đổi gần đây';
$lang['recent_days']           = 'Có bao nhiêu thay đổi gần đây được giữ (ngày)';
$lang['breadcrumbs']           = 'Số lượng mục trong thanh điều hướng "Trang đã xem". Đặt thành 0 để vô hiệu hóa.';
$lang['youarehere']            = 'Sử dụng thanh điều hướng phân cấp (có thể bạn muốn tắt tùy chọn ở trên)';
$lang['fullpath']              = 'Hiển thị đường dẫn đầy đủ của trang trong phần chân trang';
$lang['typography']            = 'Thay thế đánh máy';
$lang['dformat']               = 'Định dạng ngày (xem chức năng <a href="http://php.net/strftime">strftime</a> của PHP)';
$lang['signature']             = 'Nội dung nhập vào khi nhấn nút chữ ký trong trình sửa đổi';
$lang['showuseras']            = 'Nội dung hiển thị khi xem thành viên cuối cùng sửa đổi trang';
$lang['toptoclevel']           = 'Cấp cao nhất cho mục lục';
$lang['tocminheads']           = 'Số lượng đề mục tối thiểu cần thiết để xây dựng bảng mục lục';
$lang['maxtoclevel']           = 'Cấp tối đa cho bảng mục lục';
$lang['maxseclevel']           = 'Cấp tối đa cho phần mục sửa đổi';
$lang['camelcase']             = 'Sử dụng CamelCase cho các liên kết';
$lang['deaccent']              = 'Cách làm sạch tên trang';
$lang['useheading']            = 'Sử dụng đề mục đầu tiên làm tên trang';
$lang['sneaky_index']          = 'Theo mặc định, DokuWiki sẽ hiển thị tất cả các không gian tên trong sơ đồ trang web. Bật tùy chọn này sẽ ẩn những nơi mà thành viên không có quyền đọc. Điều này có thể dẫn đến việc ẩn các không gian tên con có thể truy cập, có thể làm cho chỉ mục không thể sử dụng được với các thiết lập Danh sách quyền truy cập (ACL) nhất định.';
$lang['hidepages']             = 'Ẩn các trang khớp với biểu thức chính quy này khỏi tìm kiếm, sơ đồ trang web và các chỉ mục tự động khác';
$lang['useacl']                = 'Sử dụng Danh sách kiểm soát truy cập';
$lang['autopasswd']            = 'Tự động tạo mật khẩu';
$lang['authtype']              = 'Xác thực phụ trợ';
$lang['passcrypt']             = 'Phương thức mã hóa mật khẩu';
$lang['defaultgroup']          = 'Nhóm mặc định, tất cả thành viên mới sẽ được đặt trong nhóm này';
$lang['superuser']             = 'Siêu thành viên - danh sách được phân tách bằng nhóm, thành viên hoặc dấu phẩy user1,@group1,user2 có toàn quyền truy cập vào tất cả các trang và chức năng bất kể cài đặt trong Danh sách kiểm soát truy cập (ACL)';
$lang['manager']               = 'Quản lý - nhóm, thành viên hoặc danh sách được phân tách bằng dấu phẩy user1,@group1,user2 có quyền truy cập vào một số chức năng quản lý';
$lang['profileconfirm']        = 'Xác nhận thay đổi hồ sơ bằng mật khẩu';
$lang['rememberme']            = 'Cho phép cookie đăng nhập vĩnh viễn (nhớ tôi)';
$lang['disableactions']        = 'Vô hiệu hóa hành động DokuWiki';
$lang['disableactions_check']  = 'Kiểm tra';
$lang['disableactions_subscription'] = 'Đăng ký/Hủy đăng ký';
$lang['disableactions_wikicode'] = 'Xem mã nguồn/Xuất Raw';
$lang['disableactions_profile_delete'] = 'Xóa tài khoản cá nhân';
$lang['disableactions_other']  = 'Hành động khác (được phân tách bằng dấu phẩy)';
$lang['disableactions_rss']    = 'Đồng bộ XML (RSS)';
$lang['auth_security_timeout'] = 'Thời gian chờ xác thực bảo mật (giây)';
$lang['securecookie']          = 'Có nên gửi cookie qua HTTPS qua trình duyệt HTTPS không? Vô hiệu hóa tùy chọn này khi chỉ đăng nhập wiki của bạn được bảo mật bằng SSL nhưng việc duyệt wiki được thực hiện không bảo mật.';
$lang['remote']                = 'Kích hoạt hệ thống API từ xa. Cho phép các ứng dụng khác truy cập wiki thông qua XML-RPC hoặc các cơ chế khác.';
$lang['remoteuser']            = 'Hạn chế quyền truy cập API từ xa đối với các nhóm hoặc thành viên được phân tách bằng dấu phẩy ở đây. Để trống sẽ cho phép mọi người truy cập.';
$lang['usewordblock']          = 'Chặn spam dựa trên danh sách từ';
$lang['relnofollow']           = 'Dùng rel="ugc nofollow" cho liên kết ngoài';
$lang['indexdelay']            = 'Thời gian trễ trước khi lập chỉ mục (giây)';
$lang['mailguard']             = 'Làm xáo trộn địa chỉ thư điện tử';
$lang['iexssprotect']          = 'Kiểm tra tập tin đã tải lên có thể có mã JavaScript hoặc HTML độc hại';
$lang['usedraft']              = 'Tự động lưu bản nháp trong khi đang sửa đổi';
$lang['htmlok']                = 'Cho phép nhúng HTML';
$lang['phpok']                 = 'Cho phép nhúng PHP';
$lang['locktime']              = 'Thời gian tối đa cho các tập tin khóa (giây)';
$lang['cachetime']             = 'Thời gian tối đa cho bộ đệm (giây)';
$lang['target____wiki']        = 'Cửa sổ đích cho các liên kết nội bộ';
$lang['target____interwiki']   = 'Cửa sổ đích cho các liên kết liên wiki';
$lang['target____extern']      = 'Cửa sổ đích cho các liên kết ngoài';
$lang['target____media']       = 'Cửa sổ đích cho các liên kết phương tiện';
$lang['target____windows']     = 'Cửa sổ đích cho các liên kết cửa sổ';
$lang['mediarevisions']        = 'Kích hoạt Mediarevisions?';
$lang['refcheck']              = 'Kiểm tra tập tin phương tiện xem có còn đang được sử dụng không trước khi xóa';
$lang['gdlib']                 = 'Phiên bản GD Lib';
$lang['im_convert']            = 'Đường dẫn đến công cụ chuyển đổi của ImageMagick';
$lang['jpg_quality']           = 'Chất lượng nén JPEG (0-100)';
$lang['fetchsize']             = 'Kích thước tối đa (byte) fetch.php có thể tải xuống từ các URL bên ngoài, ví dụ: để lưu trữ và thay đổi kích thước hình ảnh bên ngoài.';
$lang['subscribers']           = 'Cho phép thành viên đăng ký thay đổi trang bằng thư điện tử';
$lang['subscribe_time']        = 'Thời gian danh sách đăng ký và thông báo được gửi (giây); Thời gian này phải nhỏ hơn thời gian được chỉ định trong recent_days.';
$lang['notify']                = 'Luôn gửi thông báo thay đổi đến địa chỉ thư điện tử này';
$lang['registernotify']        = 'Luôn gửi thông tin về thành viên mới đăng ký đến địa chỉ thư điện tử này';
$lang['mailfrom']              = 'Đia chỉ thư điện tử người gửi sử dụng cho thư tự động';
$lang['mailreturnpath']        = 'Địa chỉ thư điện tử người nhận cho thông báo không cung cấp';
$lang['mailprefix']            = 'Tiền tố chủ đề thư điện tử sử dụng cho thư tự động. Để trống nếu muốn sử dụng tiêu đề wiki';
$lang['htmlmail']              = 'Gửi tìm kiếm tốt hơn, nhưng kích thước lớn hơn thư điện tử HTML nhiều phần. Vô hiệu hóa cho thư chỉ có văn bản đơn thuần .';
$lang['dontlog']               = 'Vô hiệu hóa ghi nhật ký đối với các loại nhật ký này.';
$lang['sitemap']               = 'Tạo sơ đồ trang web của Google (sitemap) thường xuyên (tính theo ngày). Đặt thành 0 để vô hiệu hóa';
$lang['rss_type']              = 'Loại nguồn cấp dữ liệu XML';
$lang['rss_linkto']            = 'Liên kết đến nguồn cấp dữ liệu XML ';
$lang['rss_content']           = 'Hiển thị gì trong các mục nguồn cấp dữ liệu XML?';
$lang['rss_update']            = 'Khoảng thời gian cập nhật nguồn cấp dữ liệu XML (giây)';
$lang['rss_show_summary']      = 'Tóm tắt nguồn cấp dữ liệu XML trong tiêu đề';
$lang['rss_show_deleted']      = 'Hiển thị nguồn cấp dữ liệu XML đã xóa';
$lang['rss_media']             = 'Loại thay đổi nào sẽ được liệt kê trong nguồn cấp dữ liệu XML?';
$lang['rss_media_o_both']      = 'cả hai';
$lang['rss_media_o_pages']     = 'trang';
$lang['rss_media_o_media']     = 'phương tiện';
$lang['updatecheck']           = 'Kiểm tra cập nhật và cảnh báo bảo mật? DokuWiki cần kết nối với update.dokuwiki.org  để sử dụng tính năng này.';
$lang['userewrite']            = 'Sử dụng URL đẹp';
$lang['useslash']              = 'Sử dụng dấu gạch chéo làm dấu phân cách không gian tên trong URL';
$lang['sepchar']               = 'Phân cách từ trong tên trang';
$lang['canonical']             = 'Sử dụng URL hoàn toàn kinh điển';
$lang['fnencode']              = 'Phương pháp mã hóa tên tập tin không phải ASCII.';
$lang['autoplural']            = 'Kiểm tra các hình thức số nhiều trong các liên kết';
$lang['compression']           = 'Phương pháp nén cho các tập tin attic ';
$lang['gzip_output']           = 'Sử dụng mã hóa nội dung gzip cho xhtml';
$lang['compress']              = 'Đầu ra CSS và javascript nhỏ gọn';
$lang['cssdatauri']            = 'Kích thước tính theo byte mà hình ảnh được tham chiếu trong tập tin CSS nên được nhúng ngay vào bảng định kiểu để giảm yêu cầu đầu đề HTTP phía trước. <code>400</code> đến <code>600</code> bytes là các giá trị tốt. Đặt thành <code>0</code> để vô hiệu hóa.';
$lang['send404']               = 'Gửi "HTTP 404/Không tìm thấy trang" cho những trang không tồn tại';
$lang['broken_iua']            = 'Chức năng ign_user_abort có bị hỏng trên hệ thống của bạn không? Điều này có thể khiến chỉ mục tìm kiếm không hoạt động. IIS + PHP/CGI được biết sẽ bị hỏng. Xem <a href="http://bugs.dokuwiki.org/?do=details&amp;task_id=852">Bug 852</a> để biết thêm thông tin.';
$lang['xsendfile']             = 'Sử dụng đầu đề X-Sendfile cho phép máy chủ web cung cấp các tập tin tĩnh? Máy chủ web của bạn cần hỗ trợ cái này.';
$lang['renderer_xhtml']        = 'Trình kết xuất để sử dụng cho đầu ra wiki chính (xhtml)';
$lang['renderer__core']        = '%s (lõi dokuwiki)';
$lang['search_nslimit']        = 'Giới hạn tìm kiếm trong không gian tên X hiện tại. Khi tìm kiếm được thực hiện từ một trang trong không gian tên sâu hơn, không gian tên X đầu tiên sẽ được thêm vào dưới dạng bộ lọc';
$lang['search_fragment']       = 'Chỉ định hành vi tìm kiếm đoạn mặc định';
$lang['search_fragment_o_exact'] = 'chính xác';
$lang['search_fragment_o_starts_with'] = 'bắt đầu với';
$lang['search_fragment_o_ends_with'] = 'kết thúc bằng';
$lang['search_fragment_o_contains'] = 'chứa';
$lang['trustedproxy']          = 'Những proxy chuyển tiếp tin cậy khớp với biểu thức chính quy này về IP máy khách thực mà họ báo cáo. Mặc định phù hợp với những mạng cục bộ. Để trống để tin tưởng không có proxy.';
$lang['_feature_flags']        = 'Cờ đặc trưng';
$lang['defer_js']              = 'Trì hoãn javascript được thực thi sau khi HTML của trang được phân tích cú pháp. Cải thiện tốc độ trang nhận thức nhưng có thể phá vỡ một số lượng nhỏ plugin.';
$lang['dnslookups']            = 'DokuWiki sẽ tra cứu tên máy chủ cho các địa chỉ IP từ xa của thành viên sửa đổi trang. Nếu bạn có máy chủ DNS chậm hoặc không hoạt động hoặc không muốn tính năng này, hãy tắt tùy chọn này';
$lang['jquerycdn']             = 'Các tập tin script jQuery và jQuery UI có nên được tải từ CDN không? Việc này thêm các yêu cầu HTTP bổ sung, nhưng có thể tải tập tin nhanh hơn và người dùng có thể đã lưu chúng vào bộ nhớ cache.';
$lang['jquerycdn_o_0']         = 'Không có CDN, chỉ tải nội bộ';
$lang['jquerycdn_o_jquery']    = 'CDN tại code.jquery.com';
$lang['jquerycdn_o_cdnjs']     = 'CDN tại cdnjs.com';
$lang['proxy____host']         = 'Tên máy chủ Proxy';
$lang['proxy____port']         = 'Cổng Proxy ';
$lang['proxy____user']         = 'Tên thành viên Proxy ';
$lang['proxy____pass']         = 'Mật khẩu Proxy ';
$lang['proxy____ssl']          = 'Sử dụng SSL khi kết nối với proxy';
$lang['proxy____except']       = 'Biểu thức chính quy để khớp với các URL mà proxy nên được bỏ qua.';
$lang['license_o_']            = 'Không chọn';
$lang['typography_o_0']        = 'Không';
$lang['typography_o_1']        = 'không bao gồm dấu ngoặc đơn';
$lang['typography_o_2']        = 'bao gồm cả dấu ngoặc đơn (có thể không phải lúc nào cũng hoạt động)';
$lang['userewrite_o_0']        = 'không';
$lang['userewrite_o_2']        = 'Nội bộ DokuWiki ';
$lang['deaccent_o_0']          = 'tắt';
$lang['deaccent_o_1']          = 'xóa dấu';
$lang['deaccent_o_2']          = 'La tinh hóa';
$lang['gdlib_o_0']             = 'Không có sẵn GD Lib ';
$lang['gdlib_o_1']             = 'Phiên bản 1.x';
$lang['gdlib_o_2']             = 'Tự động phát hiện';
$lang['rss_content_o_abstract'] = 'Abstract';
$lang['rss_content_o_diff']    = 'Unified Diff';
$lang['rss_content_o_htmldiff'] = 'bảng HTML định dạng khác';
$lang['rss_content_o_html']    = 'Nội dung trang HTML đầy đủ';
$lang['rss_linkto_o_diff']     = 'xem khác biệt';
$lang['rss_linkto_o_page']     = 'Trang đã xem lại';
$lang['rss_linkto_o_rev']      = 'Danh sách phiên bản';
$lang['rss_linkto_o_current']  = 'trang hiện tại';
$lang['compression_o_0']       = 'không';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'không sử dụng';
$lang['xsendfile_o_1']         = 'Đầu đề lighttpd độc quyền (trước khi phát hành 1.5)';
$lang['xsendfile_o_2']         = 'Đầu đề X-Sendfile tiêu chuẩn';
$lang['xsendfile_o_3']         = 'Đầu đề Nginx X-Accel-Redirect độc quyền';
$lang['showuseras_o_loginname'] = 'Tên đăng nhập';
$lang['showuseras_o_username'] = 'Tên đầy đủ của thành viên';
$lang['showuseras_o_username_link'] = 'Tên đầy đủ của thành viên dưới dạng liên kết thành viên liên wiki';
$lang['showuseras_o_email']    = 'Địa chỉ thư điện tử của thành viên (bị xáo trộn theo cài đặt mailguard)';
$lang['showuseras_o_email_link'] = 'Địa chỉ thư điện tử của thành viên dưới dạng mailto: link';
$lang['useheading_o_0']        = 'Không bao giờ';
$lang['useheading_o_navigation'] = 'Chỉ điều hướng';
$lang['useheading_o_content']  = 'Chỉ nội dung Wiki';
$lang['useheading_o_1']        = 'Luôn luôn';
$lang['readdircache']          = 'Thời gian tối đa cho bộ nhớ cache readdir (giây)';
